# This R script replicates the key analyses performed in THE 
# DISTRIBUTION OF AGE DISPARITIES IN CONIFER CHARCOAL FROM 
# ARCHAEOLOGICAL STRUCTURES AND APPLICATIONS FOR 
# TREE-RING-RADIOCARBON DATING
# Nicholas V. Kessler

# The script performs the step-wise statistical tests to partition
# the sample, fits probability functions to the empirical
# distributions, and reproduces Figures 3, 4, and 5.

require("MASS")
require("fitdistrplus")

# set wd to access file named "Supplement 2" 
# available as Supplementary Materials

setwd("~/projects/dating offset/Submission") 

# load file 

df <- read.csv("Supplement 2.csv")

# summarize variables

summary(df$mode)
summary(df$width)
summary(df$gap)
summary(df$age)

# view the sites in the dataset
unique(df$name)
length(unique(df$`name`))

# set age cutoff for old and young trees

cutoff<- 50

# examine the distribution of sample condition

unique(df$form)
table(df$form)

# convert forms to simple categories: 1 = cross-sections, 2 = frags 

df$form[df$form=="char xs"|df$form=="char wd xs"|df$form=="char wd pxs"|
          df$form=="char pxs"|df$form=="wd xs"|df$form=="wd core"]<- 1

df$form[df$form=="char wd frags"|df$form=="char frags"|df$form=="wd frags"|
          df$form=="rtd wd frags"]<- 2

# view species breakdown

table(df$species)

# view sample sizes for cutting date cluster range
sum(df$width>5)
sum(df$width<=5)

# view the sample sizes by taphonomic form
sum(df$form==1) #xs
sum(df$form==2) #frags

# view the totals for young and old trees
sum(df$age<=50)
sum(df$age>50)

# combine pine and fir into a single category

df$species[df$species=="PNN"|df$species=="PP"|df$species=="DF"]<- "PF"

## Examine the total age offset distribution and statistical models for it

# Args for scaling plots
limVals<- c(min(df$gap)-10,
            quantile(df$gap,0.99),
            max(df$gap)+10)

bks=seq(limVals[1],limVals[3],5)

# empirical distribution of all age offsets
layout(1)
par(oma=c(4.5,4,2,3),mar=c(1,0.5,1,0.5),family='sans')

hist(df$gap,freq=F,
     breaks=bks,border=NULL,col='gray',main="",ylab="",xlab="",yaxt='n')
axis(2)
mtext("Density",2,3)
mtext("Age Offset (years)",1,3)

# model the whole dataset
length(df$gap)
summary(df$gap)
table(df$gap)
AIC(fitdistr(df$gap+abs(min(df$gap))+1,densfun="lognormal"),
    fitdistr(df$gap+abs(min(df$gap)),densfun="exponential"))
r<- fitdistr(df$gap+abs(min(df$gap))+1,densfun="lognormal")
(r$estimate)
ks.test(df$gap+abs(min(df$gap))+1,"plnorm",r$estimate[1],r$estimate[2])

lines(seq(min(df$gap),max(df$gap),length.out=length(0:max(df$gap))),
      dlnorm(seq(0,max(df$gap),length.out=length(0:max(df$gap))),
             r$estimate[1],r$estimate[2]),lwd=2)

r<- fitdist(df$gap+abs(min(df$gap))+1, "lnorm",method="mge",gof="ADL")
(r$estimate)
ks.test(df$gap+abs(min(df$gap))+1,"plnorm",r$estimate[1],r$estimate[2])

## Segregate groupings based on the combinations of the three different 
## classes
# single event, young trees, xs, jun
g1<- df$gap[df$width<=5 & df$age<=cutoff & df$form == 1 
            & df$species == "JUN"]
# single event, young trees, xs, pine/fir
g2<- df$gap[df$width<=5 & df$age<=cutoff & df$form == 1 
            & df$species == "PF"]
# single event, young trees, frags, jun
g3<- df$gap[df$width<=5 & df$age<=cutoff & df$form == 2
            & df$species == "JUN"]
# single event, young trees, frags, pine/fir
g4<- df$gap[df$width<=5 & df$age<=cutoff & df$form == 2
            & df$species == "PF"]
# single event, old trees, xs, jun
g5<- df$gap[df$width<=5 & df$age>cutoff & df$form == 1
            & df$species == "JUN"]
# single event, old trees, xs, pine/fir
g6<- df$gap[df$width<=5 & df$age>cutoff & df$form == 1
            & df$species == "PF"]
# single event, old trees, frags, jun
g7<- df$gap[df$width<=5 & df$age>cutoff & df$form == 2
            & df$species == "JUN"]
# single event, old trees, frags, pine/fir
g8<- df$gap[df$width<=5 & df$age>cutoff & df$form == 2
            & df$species == "PF"]
# intragen event, young trees, xs, jun
g9<- df$gap[df$width>5 & df$width<=30 & df$age<=cutoff & df$form == 1
            & df$species == "JUN"]
# intragen event, young trees, xs, pine/fir
g10<- df$gap[df$width>5 & df$width<=30 & df$age<=cutoff & df$form == 1
             & df$species == "PF"]
# intragen event, young trees, frags, jun
g11<- df$gap[df$width>5 & df$width<=30 & df$age<=cutoff & df$form == 2
             & df$species == "JUN"]
# intragen event, young trees, frags, pine/fir
g12<- df$gap[df$width>5 & df$width<=30 & df$age<=cutoff & df$form == 2
             & df$species == "PF"]
# intragen event, old trees, xs, jun
g13<- df$gap[df$width>5 & df$width<=30 & df$age>cutoff & df$form == 1
             & df$species == "JUN"]
# intragen event, old trees, xs, pine/fir
g14<- df$gap[df$width>5 & df$width<=30 & df$age>cutoff & df$form == 1
             & df$species == "PF"]
# intragen event, old trees, frags, jun
g15<- df$gap[df$width>5 & df$width<=30 & df$age>cutoff & df$form == 2
             & df$species == "JUN"]
# intragen event, old trees, frags, pine/fir
g16<- df$gap[df$width>5 & df$width<=30 & df$age>cutoff & df$form == 2
             & df$species == "PF"]

## Test whether categorical effects are significant across groups
## The prediction is that older trees, fragmented specimens, and longer duration
## cutting date clusters increase the distribution of age offsets 

# effect of tree taxa
wilcox.test(x=g2,y=g1,alternative="two.sided") # single young xs
wilcox.test(x=g10,y=g9,alternative="two.sided") # intragen young xs
wilcox.test(x=g4,y=g3,alternative="two.sided") # single young frags
wilcox.test(x=g12,y=g11,alternative="two.sided") # intragen young frags
wilcox.test(x=g6,y=g5,alternative="two.sided") # single old xs
wilcox.test(x=g14,y=g13,alternative="two.sided") # intragen old xs
wilcox.test(x=g8,y=g7,alternative="two.sided") # single old frags
wilcox.test(x=g16,y=g15,alternative="two.sided") # intrgen old frags

## Tree taxa has no significant effect on age offset
## new classes
# single event, young trees, xs
g1<- df$gap[df$width<=5 & df$age<=cutoff & df$form == 1]
# single event, young trees, frags
g2<- df$gap[df$width<=5 & df$age<=cutoff & df$form == 2]
# single event, old trees, xs
g3<- df$gap[df$width<=5 & df$age>cutoff & df$form == 1]
# single event, old trees, frags
g4<- df$gap[df$width<=5 & df$age>cutoff & df$form == 2]
# intragen event, young trees, xs
g5<- df$gap[df$width>5 & df$width<=30 & 
              df$age<=cutoff & df$form == 1]
# intragen event, young trees, frags
g6<- df$gap[df$width>5 & df$width<=30 & 
              df$age<=cutoff & df$form == 2]
# intragen event, old trees, xs
g7<- df$gap[df$width>5 & df$width<=30 & 
              df$age>cutoff & df$form == 1]
# intragen event, old trees, frags
g8<- df$gap[df$width>5 & df$width<=30 & 
              df$age>cutoff & df$form == 2]

# effect of event duration
wilcox.test(x=g5,y=g1,alternative="greater") # young xs
wilcox.test(x=g6,y=g2,alternative="greater") # young frags
wilcox.test(x=g7,y=g3,alternative="greater") # old xs
wilcox.test(x=g8,y=g4,alternative="greater") # old frags

## Event duration has no significant effect on age offset
## new classes
# young trees, xs
g1<- df$gap[df$age<=cutoff & df$form == 1]
# young trees, frags
g2<- df$gap[df$age<=cutoff & df$form == 2]
# old trees, xs
g3<- df$gap[df$age>cutoff & df$form == 1]
# old trees, frags
g4<- df$gap[df$age>cutoff & df$form == 2]

# effect of fragmentation
wilcox.test(x=g2,y=g1,alternative="greater") # young
wilcox.test(x=g4,y=g3,alternative="greater") # old

# effect of tree age
wilcox.test(x=g3,y=g1,alternative="greater") # xs
wilcox.test(x=g4,y=g2,alternative="greater") # frags

## summary stats and model the age offset distributions 
## for each group and summarize

# groups
summary(g1)
length(g1)
table(g1)
AIC(fitdistr(g1+abs(min(g1))+1,densfun="lognormal"),
    fitdistr(g1+abs(min(g1)),densfun="exponential"))
r1<- fitdistr(g1+abs(min(g1))+1,densfun="lognormal")
(r1$estimate)
ks.test(g1+abs(min(g1))+1,"plnorm",r1$estimate[1],r1$estimate[2])

summary(g2)
length(g2)
table(g2)
AIC(fitdistr(g2+abs(min(g2))+1,densfun="lognormal"),
    fitdistr(g2+abs(min(g2)),densfun="exponential"))
r2<- fitdistr(g2+abs(min(g2))+1,densfun="lognormal")
(r2$estimate)
ks.test(g2+abs(min(g2))+1,"plnorm",r2$estimate[1],r2$estimate[2])

summary(g3)
length(g3)
table(g3)
AIC(fitdistr(g3+abs(min(g3))+1,densfun="lognormal"),
    fitdistr(g3+abs(min(g3)),densfun="exponential"))
r3<- fitdistr(g3+abs(min(g3))+1,densfun="lognormal")
(r3$estimate)
ks.test(g3+abs(min(g3))+1,"plnorm",r3$estimate[1],r3$estimate[2])

summary(g4)
length(g4)
table(g4)
AIC(fitdistr(g4+abs(min(g4))+1,densfun="lognormal"),
    fitdistr(g4+abs(min(g4)),densfun="exponential"))
r4<- fitdistr(g4+abs(min(g4))+1,densfun="lognormal")
(r4$estimate)
ks.test(g4+abs(min(g4))+1,"plnorm",r4$estimate[1],r4$estimate[2])

# look at group 4 again
# K-S test suggests that there could be more varibales
r4<- fitdist(g4+abs(min(g4))+1, "lnorm",method="mge",gof="ADL")

ks.test(g4+abs(min(g4))+1,"plnorm",r4$estimate[1],r4$estimate[2])

r4

# box plot of each group
layout(1)
boxplot(list(g1,g2,g3,g4),outline=F)
mtext("Sample Group",1,2.25)
mtext("Age Disparity (yrs)",2,2.5)

# distribution of each group

layout(mat=matrix(c(1,2,3,4),2,2,byrow=T))
par(mar=c(2.25,2.25,1,0.75),oma=c(3,2.5,2.5,2.5),cex.axis=1)

hist(g1,freq=F,xlim=c(limVals[1],limVals[2]),
     breaks=bks,border=NA,col='gray',main="",ylab="",xlab="")
d1<- density(g1,from=min(g1),kernel="ep")
xv1<- (d1$x[d1$y>quantile(d1$y,0.025) & d1$y<quantile(d1$y,0.975)])
yv1<- (d1$y[d1$y>quantile(d1$y,0.025) & d1$y<quantile(d1$y,0.975)])
#polygon(x = c(xv1,rev(xv1)),
#        y = c(yv1,rep(0,length(yv1))),
#        col=rgb(0.75,0.05,0.1,0.5),border=NA)
lines(min(g1):(max(g1)-abs(min(g1))),
      dlnorm(0:max(g1),r1$estimate[1],r1$estimate[2]),lwd=1.5)
box(which = "figure")
mtext("Cross-sections",3,1.25,cex=1.2)

hist(g2,freq=F,xlim=c(limVals[1],limVals[2]),
     breaks=bks,border=NA,col='gray',main="",ylab="",xlab="")
d2<- density(g2,from=min(g2),kernel="ep")
#lines(d2,lwd=2,col='red')
xv2<- (d2$x[d2$y>quantile(d2$y,0.025) & d2$y<quantile(d2$y,0.975)])
yv2<- (d2$y[d2$y>quantile(d2$y,0.025) & d2$y<quantile(d2$y,0.975)])
#polygon(x = c(xv2,rev(xv2)),
#        y = c(yv2,rep(0,length(yv2))),
#        col=rgb(0.75,0.05,0.1,0.5),border=NA)
lines(min(g2):(max(g2)-abs(min(g2))),
      dlnorm(0:max(g2),r2$estimate[1],r2$estimate[2]),lwd=1.5)
box(which = "figure")
mtext("Fragments",3,1.25,cex=1.2)
mtext("Younger Trees",4,1.25,cex=1.2)

hist(g3,freq=F,xlim=c(limVals[1],limVals[2]),
     breaks=bks,border=NA,col='gray',main="",ylab="",xlab="")
d3<- density(g3,from=min(g3),kernel="ep")
#lines(d2,lwd=2,col='red')
xv3<- (d3$x[d3$y>quantile(d3$y,0.025) & d3$y<quantile(d3$y,0.975)])
yv3<- (d3$y[d3$y>quantile(d3$y,0.025) & d3$y<quantile(d3$y,0.975)])
#polygon(x = c(xv3,rev(xv3)),
#        y = c(yv3,rep(0,length(yv3))),
#        col=rgb(0.75,0.05,0.1,0.5),border=NA)
lines(min(g3):(max(g3)-abs(min(g3))),
      dlnorm(0:max(g3),r3$estimate[1],r3$estimate[2]),lwd=1.5)
box(which = "figure")

hist(g4,freq=F,xlim=c(limVals[1],limVals[2]),
     breaks=bks,border=NA,col='gray',main="",ylab="",xlab="")
d4<- density(g4,from=min(g4),kernel="ep")
#lines(d2,lwd=2,col='red')
xv4<- (d4$x[d4$y>quantile(d4$y,0.025) & d4$y<quantile(d4$y,0.975)])
yv4<- (d4$y[d4$y>quantile(d4$y,0.025) & d4$y<quantile(d4$y,0.975)])
#polygon(x = c(xv4,rev(xv4)),
#        y = c(yv4,rep(0,length(yv4))),
#        col=rgb(0.75,0.05,0.1,0.5),border=NA)
lines(min(g4):(max(g4)-abs(min(g4))),
      dlnorm(0:max(g4),r4$estimate[1],r4$estimate[2]),lwd=1.5)
box(which = "figure")
mtext("Older trees",4,1.25,cex=1.2)
mtext("Age Offset (years)",1,1.25,-5)
mtext("Density",2,1.25,-5)

# r^2 between models and empirical data

mean(replicate(99999,cor(sort(rlnorm(length(g1),r1$estimate[1],
                                     r1$estimate[2])),sort(g1))))^2

mean(replicate(99999,cor(sort(rlnorm(length(g2),r2$estimate[1],
                                     r2$estimate[2])),sort(g2))))^2

mean(replicate(99999,cor(sort(rlnorm(length(g3),r3$estimate[1],
                                     r3$estimate[2])),sort(g3))))^2

mean(replicate(99999,cor(sort(rlnorm(length(g4),r4$estimate[1],
                                     r4$estimate[2])),sort(g4))))^2

